@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 
+from django import VERSION
+
+
 DATABASE_ENGINE = 'sqlite3'
 
 SITE_ID = 1
@@ -30,4 +33,8 @@ TEMPLATE_LOADERS = (
     'django.template.loaders.app_directories.Loader',
 )
 
-TEST_RUNNER = 'discover_runner.DiscoverRunner'
+if VERSION[:2] < (1, 6):
+    TEST_RUNNER = 'discover_runner.DiscoverRunner'
+
+GEO_REDIS_TYPE = 'pk'
+GEO_REDIS_DB = 5
